@@ -1,4 +1,6 @@
-__version__ = "0.2.1"
+__debug_build__ = False
+__disable_shaders__ = True
+__version__ = "0.2.2"
 __variant__ = "beta"
 
 import sys
@@ -18,7 +20,7 @@ import base64
 import threading
 
 from kivy.logger import Logger, LOG_LEVELS
-if args.verbose:
+if __debug_build__ or args.verbose:
     Logger.setLevel(LOG_LEVELS["debug"])
 else:
     Logger.setLevel(LOG_LEVELS["error"])
@@ -33,6 +35,10 @@ from kivy.core.clipboard import Clipboard
 from kivy.base import EventLoop
 from kivy.clock import Clock
 from kivy.lang.builder import Builder
+from kivy.effects.scroll import ScrollEffect
+from kivy.uix.screenmanager import ScreenManager
+from kivy.uix.screenmanager import FadeTransition, NoTransition
+from kivy.effects.dampedscroll import DampedScrollEffect
 
 if RNS.vendor.platformutils.get_platform() == "android":
     from sideband.core import SidebandCore
@@ -59,9 +65,10 @@ else:
     from .ui.messages import Messages, ts_format
     from .ui.helpers import ContentNavigationDrawer, DrawerList, IconListItem
 
-from kivy.metrics import dp
-from kivymd.uix.button import MDFlatButton
+from kivy.metrics import dp, sp
+from kivymd.uix.button import MDFlatButton, MDRectangleFlatButton
 from kivymd.uix.dialog import MDDialog
+from kivymd.color_definitions import colors
 
 dark_theme_text_color = "ddd"
 
@@ -83,13 +90,14 @@ class SidebandApp(MDApp):
         self.app_state = SidebandApp.STARTING
         self.android_service = None
         self.app_dir = plyer.storagepath.get_application_dir()
+        self.shaders_disabled = __disable_shaders__
 
         if RNS.vendor.platformutils.get_platform() == "android":
-            self.sideband = SidebandCore(self, is_client=True, android_app_dir=self.app_dir)
+            self.sideband = SidebandCore(self, is_client=True, android_app_dir=self.app_dir, verbose=__debug_build__)
         else:
-            self.sideband = SidebandCore(self, is_client=False, verbose=args.verbose)
+            self.sideband = SidebandCore(self, is_client=False, verbose=(args.verbose or __debug_build__))
 
-        self.update_ui_theme()
+        self.set_ui_theme()
 
         self.conversations_view = None
         self.sync_dialog = None
@@ -160,16 +168,40 @@ class SidebandApp(MDApp):
     # General helpers                               #
     #################################################
 
-    def update_ui_theme(self):
+    def set_ui_theme(self):
         self.theme_cls.material_style = "M3"
         self.theme_cls.widget_style = "android"
         self.theme_cls.primary_palette = "BlueGray"
         self.theme_cls.accent_palette = "Orange"
+
         if self.sideband.config["dark_ui"]:
             self.theme_cls.theme_style = "Dark"
         else:
             self.theme_cls.theme_style = "Light"
 
+        self.update_ui_colors()
+
+    def update_ui_colors(self):
+        if self.sideband.config["dark_ui"]:
+            self.color_reject = colors["DeepOrange"]["900"]
+            self.color_accept = colors["LightGreen"]["700"]
+        else:
+            self.color_reject = colors["DeepOrange"]["800"]
+            self.color_accept = colors["LightGreen"]["700"]
+
+    def update_ui_theme(self):
+        if self.sideband.config["dark_ui"]:
+            self.theme_cls.theme_style = "Dark"
+        else:
+            self.theme_cls.theme_style = "Light"
+
+        self.update_ui_colors()
+
+        st = time.time()
+        RNS.log("Recursing widgets...")
+        for wid in self.root.ids:
+            RNS.log("Found: "+str(wid)+str(self.root.ids[wid]))
+
     def set_bars_colors(self):
         if RNS.vendor.platformutils.get_platform() == "android":
             set_bars_colors(
@@ -191,22 +223,41 @@ class SidebandApp(MDApp):
             mActivity.startActivity(shareIntent)
 
     def on_pause(self):
+        RNS.log("App pausing...", RNS.LOG_DEBUG)
         self.sideband.setstate("app.running", True)
         self.sideband.setstate("app.foreground", False)
         self.app_state = SidebandApp.PAUSED
         self.sideband.should_persist_data()
+        if self.conversations_view != None:
+            self.root.ids.conversations_scrollview.effect_cls = ScrollEffect
+            self.conversations_view.update()
+            self.root.ids.conversations_scrollview.scroll = 1
+
+        RNS.log("App paused", RNS.LOG_DEBUG)
         return True
 
     def on_resume(self):
+        RNS.log("App resuming...", RNS.LOG_DEBUG)
         self.sideband.setstate("app.running", True)
         self.sideband.setstate("app.foreground", True)
         self.sideband.setstate("wants.clear_notifications", True)
         self.app_state = SidebandApp.ACTIVE
+        if self.conversations_view != None:
+            self.root.ids.conversations_scrollview.effect_cls = ScrollEffect
+            self.conversations_view.update()
+            self.root.ids.conversations_scrollview.scroll = 1
+            
+        else:
+            RNS.log("Conversations view did not exist", RNS.LOG_DEBUG)
+
+        RNS.log("App resumed...", RNS.LOG_DEBUG)
 
     def on_stop(self):
+        RNS.log("App stopping...", RNS.LOG_DEBUG)
         self.sideband.setstate("app.running", False)
         self.sideband.setstate("app.foreground", False)
         self.app_state = SidebandApp.STOPPING
+        RNS.log("App stopped", RNS.LOG_DEBUG)
 
     def is_in_foreground(self):
         if self.app_state == SidebandApp.ACTIVE:
@@ -273,6 +324,12 @@ class SidebandApp(MDApp):
                 self.sync_dialog.ids.sync_progress.value = self.sideband.get_sync_progress()*100
                 self.sync_dialog.ids.sync_status.text = self.sideband.get_sync_status()
 
+                state = self.sideband.message_router.propagation_transfer_state
+                if state > LXMF.LXMRouter.PR_IDLE and state < LXMF.LXMRouter.PR_COMPLETE:
+                    self.widget_hide(self.sync_dialog.stop_button, False)
+                else:
+                    self.widget_hide(self.sync_dialog.stop_button, True)
+
         elif self.root.ids.screen_manager.current == "announces_screen":
             if self.sideband.getstate("app.flags.new_announces"):
                 if self.announces_view != None:
@@ -312,6 +369,7 @@ class SidebandApp(MDApp):
 
         self.root.ids.screen_manager.app = self
         self.root.ids.app_version_info.text = "Sideband v"+__version__+" "+__variant__
+        self.root.ids.nav_scrollview.effect_cls = ScrollEffect
         Clock.schedule_once(self.start_core, 3.5)
     
     # Part of the focus hack fix
@@ -371,6 +429,10 @@ class SidebandApp(MDApp):
         self.root.ids.nav_drawer.set_state("closed")
         self.sideband.should_persist_data()
 
+        self.root.ids.screen_manager.transition = NoTransition()
+        self.root.ids.screen_manager.current = "exit_screen"
+        self.sideband.setstate("app.displaying", self.root.ids.screen_manager.current)
+
         self.sideband.setstate("app.running", False)
         self.sideband.setstate("app.foreground", False)
 
@@ -434,13 +496,15 @@ class SidebandApp(MDApp):
         self.root.ids.screen_manager.transition.direction = "left"
         self.messages_view = Messages(self, context_dest)
 
+        self.root.ids.messages_scrollview.effect_cls = ScrollEffect
         for child in self.root.ids.messages_scrollview.children:
             self.root.ids.messages_scrollview.remove_widget(child)
 
         list_widget = self.messages_view.get_widget()
 
         self.root.ids.messages_scrollview.add_widget(list_widget)
-        self.root.ids.messages_scrollview.scroll_y = 0
+        self.root.ids.messages_scrollview.scroll_y = 0.001
+
         self.root.ids.messages_toolbar.title = self.sideband.peer_display_name(context_dest)
         self.root.ids.messages_scrollview.active_conversation = context_dest
         self.sideband.setstate("app.active_conversation", context_dest)
@@ -448,6 +512,8 @@ class SidebandApp(MDApp):
         self.root.ids.nokeys_text.text = ""
         self.message_area_detect()
         self.update_message_widgets()
+        self.root.ids.message_text.disabled = False
+
 
         self.root.ids.screen_manager.current = "messages_screen"
         self.sideband.setstate("app.displaying", self.root.ids.screen_manager.current)
@@ -459,6 +525,15 @@ class SidebandApp(MDApp):
         self.open_conversations(direction="right")
 
     def message_send_action(self, sender=None):
+        if self.root.ids.message_text.text == "":
+            return
+
+        def cb(dt):
+            self.message_send_dispatch(sender)
+        Clock.schedule_once(cb, 0.20)
+
+    def message_send_dispatch(self, sender=None):
+        self.root.ids.message_send_button.disabled = True
         if self.root.ids.screen_manager.current == "messages_screen":
             if self.outbound_mode_propagation and self.sideband.message_router.get_outbound_propagation_node() == None:
                 self.messages_view.send_error_dialog = MDDialog(
@@ -480,6 +555,8 @@ class SidebandApp(MDApp):
                 context_dest = self.root.ids.messages_scrollview.active_conversation
                 if self.sideband.send_message(msg_content, context_dest, self.outbound_mode_propagation):
                     self.root.ids.message_text.text = ""
+                    
+                    self.root.ids.messages_scrollview.scroll_y = 0
                     self.jobs(0)
                 else:
                     self.messages_view.send_error_dialog = MDDialog(
@@ -495,6 +572,11 @@ class SidebandApp(MDApp):
                         # elevation=0,
                     )
                     self.messages_view.send_error_dialog.open()
+        
+        def cb(dt):
+            self.root.ids.message_send_button.disabled = False
+        Clock.schedule_once(cb, 0.5)
+
 
     def message_propagation_action(self, sender):
         if self.outbound_mode_propagation:
@@ -554,6 +636,7 @@ class SidebandApp(MDApp):
             for child in self.root.ids.conversations_scrollview.children:
                 self.root.ids.conversations_scrollview.remove_widget(child)
 
+            self.root.ids.conversations_scrollview.effect_cls = ScrollEffect
             self.root.ids.conversations_scrollview.add_widget(self.conversations_view.get_widget())
 
         self.root.ids.screen_manager.current = "conversations_screen"
@@ -610,27 +693,39 @@ class SidebandApp(MDApp):
             else:
                 sl = None
 
+            self.sideband.setpersistent("lxmf.lastsync", time.time())
+            self.sideband.setpersistent("lxmf.syncretrying", False)
             self.sideband.request_lxmf_sync(limit=sl)
 
-            close_button = MDFlatButton(text="Close", font_size=dp(20))
-            # stop_button = MDFlatButton(text="Stop", font_size=dp(20))
+            close_button = MDRectangleFlatButton(text="Close",font_size=sp(18))
+            stop_button = MDRectangleFlatButton(text="Stop",font_size=sp(18), theme_text_color="Custom", line_color=self.color_reject, text_color=self.color_reject)
             dialog_content = MsgSync()
             dialog = MDDialog(
                 title="LXMF Sync via "+RNS.prettyhexrep(self.sideband.message_router.get_outbound_propagation_node()),
                 type="custom",
                 content_cls=dialog_content,
-                buttons=[ close_button ],
+                buttons=[ stop_button, close_button ],
                 # elevation=0,
             )
             dialog.d_content = dialog_content
             def dl_close(s):                
                 self.sideband.setstate("app.flags.lxmf_sync_dialog_open", False)
                 dialog.dismiss()
+                # self.sideband.cancel_lxmf_sync()
+
+            def dl_stop(s):                
+                # self.sideband.setstate("app.flags.lxmf_sync_dialog_open", False)
+                # dialog.dismiss()
                 self.sideband.cancel_lxmf_sync()
+                def cb(dt):
+                    self.widget_hide(self.sync_dialog.stop_button, True)
+                Clock.schedule_once(cb, 0.25)
 
             close_button.bind(on_release=dl_close)
+            stop_button.bind(on_release=dl_stop)
             self.sideband.setstate("app.flags.lxmf_sync_dialog_open", True)
             self.sync_dialog = dialog_content
+            self.sync_dialog.stop_button = stop_button
             dialog.open()
             dialog_content.ids.sync_progress.value = self.sideband.get_sync_progress()*100
             dialog_content.ids.sync_status.text = self.sideband.get_sync_status()
@@ -641,16 +736,16 @@ class SidebandApp(MDApp):
                 text="OK",
                 font_size=dp(20),
             )
-            no_button = MDFlatButton(
-                text="Cancel",
-                font_size=dp(20),
-            )
+
+            cancel_button = MDRectangleFlatButton(text="Cancel",font_size=sp(18))
+            create_button = MDRectangleFlatButton(text="Create",font_size=sp(18), theme_text_color="Custom", line_color=self.color_accept, text_color=self.color_accept)
+            
             dialog_content = NewConv()
             dialog = MDDialog(
                 title="New Conversation",
                 type="custom",
                 content_cls=dialog_content,
-                buttons=[ yes_button, no_button ],
+                buttons=[ create_button, cancel_button ],
                 # elevation=0,
             )
             dialog.d_content = dialog_content
@@ -668,7 +763,8 @@ class SidebandApp(MDApp):
                 if new_result:
                     dialog.d_content.ids["n_address_field"].error = False
                     dialog.dismiss()
-                    self.open_conversations()
+                    if self.conversations_view != None:
+                        self.conversations_view.update()
                 else:
                     dialog.d_content.ids["n_address_field"].error = True
                     # dialog.d_content.ids["n_error_field"].text = "Could not create conversation. Check your input."
@@ -679,8 +775,8 @@ class SidebandApp(MDApp):
             def dl_ds(s):
                 self.dialog_open = False
 
-            yes_button.bind(on_release=dl_yes)
-            no_button.bind(on_release=dl_no)
+            create_button.bind(on_release=dl_yes)
+            cancel_button.bind(on_release=dl_no)
 
             dialog.bind(on_dismiss=dl_ds)
             dialog.open()
@@ -761,6 +857,10 @@ class SidebandApp(MDApp):
                 self.sideband.save_configuration()
                 self.update_ui_theme()
 
+            def save_notifications_on(sender=None, event=None):
+                self.sideband.config["notifications_on"] = self.root.ids.settings_notifications_on.active
+                self.sideband.save_configuration()
+
             def save_start_announce(sender=None, event=None):
                 self.sideband.config["start_announce"] = self.root.ids.settings_start_announce.active
                 self.sideband.save_configuration()
@@ -773,6 +873,25 @@ class SidebandApp(MDApp):
                 self.sideband.config["lxmf_sync_limit"] = self.root.ids.settings_lxmf_sync_limit.active
                 self.sideband.save_configuration()
 
+            def save_lxmf_periodic_sync(sender=None, event=None, save=True):
+                if self.root.ids.settings_lxmf_periodic_sync.active:
+                    self.widget_hide(self.root.ids.lxmf_syncslider_container, False)
+                else:
+                    self.widget_hide(self.root.ids.lxmf_syncslider_container, True)
+
+                if save:
+                    self.sideband.config["lxmf_periodic_sync"] = self.root.ids.settings_lxmf_periodic_sync.active
+                    self.sideband.save_configuration()
+
+            def sync_interval_change(sender=None, event=None, save=True):
+                interval = (self.root.ids.settings_lxmf_sync_interval.value//300)*300
+                interval_text = RNS.prettytime(interval)
+                pre = self.root.ids.settings_lxmf_sync_periodic.text
+                self.root.ids.settings_lxmf_sync_periodic.text = "Auto sync every "+interval_text
+                if save:
+                    self.sideband.config["lxmf_sync_interval"] = interval
+                    self.sideband.save_configuration()
+
             self.root.ids.settings_lxmf_address.text = RNS.hexrep(self.sideband.lxmf_destination.hash, delimit=False)
 
             self.root.ids.settings_display_name.text = self.sideband.config["display_name"]
@@ -788,6 +907,9 @@ class SidebandApp(MDApp):
             self.root.ids.settings_propagation_node_address.bind(on_text_validate=save_prop_addr)
             self.root.ids.settings_propagation_node_address.bind(focus=save_prop_addr)
 
+            self.root.ids.settings_notifications_on.active = self.sideband.config["notifications_on"]
+            self.root.ids.settings_notifications_on.bind(active=save_notifications_on)
+
             self.root.ids.settings_dark_ui.active = self.sideband.config["dark_ui"]
             self.root.ids.settings_dark_ui.bind(active=save_dark_ui)
 
@@ -797,6 +919,18 @@ class SidebandApp(MDApp):
             self.root.ids.settings_lxmf_delivery_by_default.active = self.sideband.config["propagation_by_default"]
             self.root.ids.settings_lxmf_delivery_by_default.bind(active=save_lxmf_delivery_by_default)
 
+            self.root.ids.settings_lxmf_periodic_sync.active = self.sideband.config["lxmf_periodic_sync"]
+            self.root.ids.settings_lxmf_periodic_sync.bind(active=save_lxmf_periodic_sync)
+            save_lxmf_periodic_sync(save=False)
+
+            def sync_interval_change_cb(sender=None, event=None):
+                sync_interval_change(sender=sender, event=event, save=False)
+            self.root.ids.settings_lxmf_sync_interval.bind(value=sync_interval_change_cb)
+            self.root.ids.settings_lxmf_sync_interval.bind(on_touch_up=sync_interval_change)
+            self.root.ids.settings_lxmf_sync_interval.value = self.sideband.config["lxmf_sync_interval"]
+            sync_interval_change(save=False)
+
+
             if self.sideband.config["lxmf_sync_limit"] == None or self.sideband.config["lxmf_sync_limit"] == False:
                 sync_limit = False
             else:
@@ -983,6 +1117,7 @@ class SidebandApp(MDApp):
             for child in self.root.ids.announces_scrollview.children:
                 self.root.ids.announces_scrollview.remove_widget(child)
 
+            self.root.ids.announces_scrollview.effect_cls = ScrollEffect
             self.root.ids.announces_scrollview.add_widget(self.announces_view.get_widget())
 
     def announces_action(self, sender=None):
@@ -1005,6 +1140,8 @@ class SidebandApp(MDApp):
     def screen_transition_complete(self, sender):
         if self.root.ids.screen_manager.current == "announces_screen":
             pass
+        if self.root.ids.screen_manager.current == "conversations_screen":
+            pass
 
     ### Keys screen
     ######################################
@@ -1120,47 +1257,79 @@ class SidebandApp(MDApp):
             import webbrowser
             webbrowser.open("https://unsigned.io/sideband")
 
-        guide_text = """
+        guide_text1 = """
 [size=18dp][b]Introduction[/b][/size][size=5dp]\n \n[/size]Welcome to [i]Sideband[/i], an LXMF client for Android, Linux and macOS. With Sideband, you can communicate with other people or LXMF-compatible systems over Reticulum networks using LoRa, Packet Radio, WiFi, I2P, or anything else Reticulum supports.
 
-This short guide will give you a basic introduction to the concepts that underpin Sideband and LXMF (which is the protocol that Sideband uses to communicate). If you are not already familiar with LXMF and Reticulum, it is probably a good idea to read this guide, since Sideband is very different from other messaging apps.
-
+This short guide will give you a basic introduction to the concepts that underpin Sideband and LXMF (which is the protocol that Sideband uses to communicate). If you are not already familiar with LXMF and Reticulum, it is probably a good idea to read this guide, since Sideband is very different from other messaging apps."""
+        guide_text2 = """
 [size=18dp][b]Communication Without Subjection[/b][/size][size=5dp]\n \n[/size]Sideband is completely free, permission-less, anonymous and infrastructure-less. Sideband uses the peer-to-peer and distributed messaging system LXMF. There is no sign-up, no service providers, no "end-user license agreements", no data theft and no surveillance. You own the system.
 
-This also means that Sideband operates differently than what you might be used to. It does not need a connection to a server on the Internet to function, and you do not have an account anywhere.
-
-[size=18dp][b]Operating Principles[/b][/size][size=5dp]\n \n[/size]When Sideband is started on your device for the first time, it randomly generates a set of cryptographic keys. These keys are then used to create an LXMF address for your use. Any other endpoint in [i]any[/i] Reticulum network will be able to send data to this address, as long as there is [i]some sort of physical connection[/i] between your device and the remote endpoint. You can also move around to other Reticulum networks with this address, even ones that were never connected to the network the address was created on, or that didn't exist when the address was created. The address is yours to keep and control for as long (or short) a time you need it, and you can always delete it and create a new one.
-
+This also means that Sideband operates differently than what you might be used to. It does not need a connection to a server on the Internet to function, and you do not have an account anywhere."""
+        
+        guide_text3 = """
+[size=18dp][b]Operating Principles[/b][/size][size=5dp]\n \n[/size]When Sideband is started on your device for the first time, it randomly generates a set of cryptographic keys. These keys are then used to create an LXMF address for your use. Any other endpoint in [i]any[/i] Reticulum network will be able to send data to this address, as long as there is [i]some sort of physical connection[/i] between your device and the remote endpoint. You can also move around to other Reticulum networks with this address, even ones that were never connected to the network the address was created on, or that didn't exist when the address was created. The address is yours to keep and control for as long (or short) a time you need it, and you can always delete it and create a new one."""
+        
+        guide_text4 = """
 [size=18dp][b]Becoming Reachable[/b][/size][size=5dp]\n \n[/size]To establish reachability for any Reticulum address on a network, an [i]announce[/i] must be sent. Sideband does not do this automatically by default, but can be configured to do so every time the program starts. To send an announce manually, press the [i]Announce[/i] button in the [i]Conversations[/i] section of the program. When you send an announce, you make your LXMF address reachable for real-time messaging to the entire network you are connected to. Even in very large networks, you can expect global reachability for your address to be established in under a minute.
 
-If you don't move to other places in the network, and keep connected through the same hubs or gateways, it is generally not necessary to send an announce more often than once every week. If you change your entry point to the network, you may want to send an announce, or you may just want to stay quiet.
+If you don't move to other places in the network, and keep connected through the same hubs or gateways, it is generally not necessary to send an announce more often than once every week. If you change your entry point to the network, you may want to send an announce, or you may just want to stay quiet."""
 
+        guide_text5 = """
 [size=18dp][b]Relax & Disconnect[/b][/size][size=5dp]\n \n[/size]If you are not connected to the network, it is still possible for other people to message you, as long as one or more [i]Propagation Nodes[/i] exist on the network. These nodes pick up and hold encrypted in-transit messages for offline users. Messages are always encrypted before leaving the originators device, and nobody else than the intended recipient can decrypt messages in transit.
 
-The Propagation Nodes also distribute copies of messages between each other, such that even the failure of almost every node in the network will still allow users to sync their waiting messages. If all Propagation Nodes disappear or are destroyed, users can still communicate directly. Reticulum and LXMF will degrade gracefully all the way down to single users communicating directly via long-range data radios. Anyone can start up new propagation nodes and integrate them into existing networks without permission or coordination. Even a small and cheap device like a Rasperry Pi can handle messages for millions of users. LXMF networks are designed to be quite resilient, as long as there are people using them.
+The Propagation Nodes also distribute copies of messages between each other, such that even the failure of almost every node in the network will still allow users to sync their waiting messages. If all Propagation Nodes disappear or are destroyed, users can still communicate directly. Reticulum and LXMF will degrade gracefully all the way down to single users communicating directly via long-range data radios. Anyone can start up new propagation nodes and integrate them into existing networks without permission or coordination. Even a small and cheap device like a Rasperry Pi can handle messages for millions of users. LXMF networks are designed to be quite resilient, as long as there are people using them."""
 
-[size=18dp][b]Packets Find A Way[/b][/size][size=5dp]\n \n[/size]Connections in Reticulum networks can be wired or wireless, span many intermediary hops, run over fast links or ultra-low bandwidth radio, tunnel over the Invisible Internet (I2P), private networks, satellite connections, serial lines or anything else that Reticulum can carry data over. In most cases it will not be possible to know what path data takes in a Reticulum network, and no transmitted packets carries any identifying characteristics, apart from a destination address. There is no source addresses in Reticulum. As long as you do not reveal any connecting details between your person and your LXMF address, you can remain anonymous. Sending messages to others does not reveal [i]your[/i] address to anyone else than the intended recipient.
+        guide_text6 = """
+[size=18dp][b]Packets Find A Way[/b][/size][size=5dp]\n \n[/size]Connections in Reticulum networks can be wired or wireless, span many intermediary hops, run over fast links or ultra-low bandwidth radio, tunnel over the Invisible Internet (I2P), private networks, satellite connections, serial lines or anything else that Reticulum can carry data over. In most cases it will not be possible to know what path data takes in a Reticulum network, and no transmitted packets carries any identifying characteristics, apart from a destination address. There is no source addresses in Reticulum. As long as you do not reveal any connecting details between your person and your LXMF address, you can remain anonymous. Sending messages to others does not reveal [i]your[/i] address to anyone else than the intended recipient."""
 
+        guide_text7 = """
 [size=18dp][b]Be Yourself, Be Unknown, Stay Free[/b][/size][size=5dp]\n \n[/size]Even with the above characteristics in mind, you [b]must remember[/b] that LXMF and Reticulum is not a technology that can guarantee anonymising connections that are already de-anonymised! If you use Sideband to connect to TCP Reticulum hubs over the clear Internet, from a network that can be tied to your personal identity, an adversary may learn that you are generating LXMF traffic. If you want to avoid this, it is recommended to use I2P to connect to Reticulum hubs on the Internet. Or only connecting from within pure Reticulum networks, that take one or more hops to reach connections that span the Internet. This is a complex topic, with many more nuances than can not be covered here. You are encouraged to ask on the various Reticulum discussion forums if you are in doubt.
 
-If you use Reticulum and LXMF on hardware that does not carry any identifiers tied to you, it is possible to establish a completely free and anonymous communication system with Reticulum and LXMF clients.
-
+If you use Reticulum and LXMF on hardware that does not carry any identifiers tied to you, it is possible to establish a completely free and anonymous communication system with Reticulum and LXMF clients."""
+        
+        guide_text8 = """
 [size=18dp][b]Keyboard Shortcuts[/b][/size][size=5dp]\n \n[/size] - Ctrl+Q or Ctrl-W Shut down Sideband
  - Ctrl-D or Ctrl-S Send message
  - Ctrl-R Show Conversations
  - Ctrl-L Show Announce Stream
  - Ctrl-N New conversation
- - Ctrl-G Show guide
-
+ - Ctrl-G Show guide"""
+        
+        guide_text9 = """
 [size=18dp][b]Sow Seeds Of Freedom[/b][/size][size=5dp]\n \n[/size]It took me more than six years to design and built the entire ecosystem of software and hardware that makes this possible. If this project is valuable to you, please go to [u][ref=link]https://unsigned.io/sideband[/ref][/u] to support the project with a donation. Every donation directly makes the entire Reticulum project possible.
 
 Thank you very much for using Free Communications Systems.
 """
-        info = guide_text
+        info1 = guide_text1
+        info2 = guide_text2
+        info3 = guide_text3
+        info4 = guide_text4
+        info5 = guide_text5
+        info6 = guide_text6
+        info7 = guide_text7
+        info8 = guide_text8
+        info9 = guide_text9
+
         if self.theme_cls.theme_style == "Dark":
-            info = "[color=#"+dark_theme_text_color+"]"+info+"[/color]"
-        self.root.ids.guide_info.text = info
-        self.root.ids.guide_info.bind(on_ref_press=link_exec)
+            info1 = "[color=#"+dark_theme_text_color+"]"+info1+"[/color]"
+            info2 = "[color=#"+dark_theme_text_color+"]"+info2+"[/color]"
+            info3 = "[color=#"+dark_theme_text_color+"]"+info3+"[/color]"
+            info4 = "[color=#"+dark_theme_text_color+"]"+info4+"[/color]"
+            info5 = "[color=#"+dark_theme_text_color+"]"+info5+"[/color]"
+            info6 = "[color=#"+dark_theme_text_color+"]"+info6+"[/color]"
+            info7 = "[color=#"+dark_theme_text_color+"]"+info7+"[/color]"
+            info8 = "[color=#"+dark_theme_text_color+"]"+info8+"[/color]"
+            info9 = "[color=#"+dark_theme_text_color+"]"+info9+"[/color]"
+        self.root.ids.guide_info1.text = info1
+        self.root.ids.guide_info2.text = info2
+        self.root.ids.guide_info3.text = info3
+        self.root.ids.guide_info4.text = info4
+        self.root.ids.guide_info5.text = info5
+        self.root.ids.guide_info6.text = info6
+        self.root.ids.guide_info7.text = info7
+        self.root.ids.guide_info8.text = info8
+        self.root.ids.guide_info9.text = info9
+        self.root.ids.guide_info9.bind(on_ref_press=link_exec)
         self.root.ids.screen_manager.transition.direction = "left"
         self.root.ids.screen_manager.current = "guide_screen"
         self.root.ids.nav_drawer.set_state("closed")
