@@ -61,9 +61,11 @@ class SidebandCore():
     CONV_GROUP     = 0x02
     CONV_BROADCAST = 0x03
 
-    MAX_ANNOUNCES  = 48
+    MAX_ANNOUNCES  = 24
 
-    JOB_INTERVAL   = 1
+    SERVICE_JOB_INTERVAL   = 1
+    PERIODIC_JOBS_INTERVAL = 60
+    PERIODIC_SYNC_RETRY = 360
 
     aspect_filter = "lxmf.delivery"
     def received_announce(self, destination_hash, announced_identity, app_data):
@@ -161,6 +163,7 @@ class SidebandCore():
         self.config = {}
         # Settings
         self.config["display_name"] = "Anonymous Peer"
+        self.config["settings_notifications_on"] = False
         self.config["dark_ui"] = False
         self.config["start_announce"] = False
         self.config["propagation_by_default"] = False
@@ -169,6 +172,8 @@ class SidebandCore():
         self.config["lxmf_propagation_node"] = None
         self.config["lxmf_sync_limit"] = None
         self.config["lxmf_sync_max"] = 3
+        self.config["lxmf_periodic_sync"] = False
+        self.config["lxmf_sync_interval"] = 43200
         self.config["last_lxmf_propagation_node"] = None
         self.config["nn_home_node"] = None
         # Connectivity
@@ -212,6 +217,12 @@ class SidebandCore():
         # Migration actions from earlier config formats
         if not "dark_ui" in self.config:
             self.config["dark_ui"] = True
+        if not "lxmf_periodic_sync" in self.config:
+            self.config["lxmf_periodic_sync"] = False
+        if not "lxmf_sync_interval" in self.config:
+            self.config["lxmf_sync_interval"] = 43200
+        if not "notifications_on" in self.config:
+            self.config["notifications_on"] = True
 
         # Make sure we have a database
         if not os.path.isfile(self.db_path):
@@ -259,9 +270,7 @@ class SidebandCore():
 
 
     def notify(self, title, content, group=None, context_id=None):
-        notifications_enabled = True
-
-        if notifications_enabled:
+        if self.config["notifications_on"]:
             if RNS.vendor.platformutils.get_platform() == "android":
                 if self.getpersistent("permissions.notifications"):
                     notifications_permitted = True
@@ -373,6 +382,9 @@ class SidebandCore():
     def clear_conversation(self, context_dest):
         self._db_clear_conversation(context_dest)
 
+    def delete_announce(self, context_dest):
+        self._db_delete_announce(context_dest)
+
     def delete_conversation(self, context_dest):
         self._db_clear_conversation(context_dest)
         self._db_delete_conversation(context_dest)
@@ -666,7 +678,7 @@ class SidebandCore():
             return conv
 
     def _db_clear_conversation(self, context_dest):
-        RNS.log("Clearing conversation with "+RNS.prettyhexrep(context_dest))
+        RNS.log("Clearing conversation with "+RNS.prettyhexrep(context_dest), RNS.LOG_DEBUG)
         db = sqlite3.connect(self.db_path)
         dbc = db.cursor()
 
@@ -677,7 +689,7 @@ class SidebandCore():
         db.close()
 
     def _db_delete_conversation(self, context_dest):
-        RNS.log("Deleting conversation with "+RNS.prettyhexrep(context_dest))
+        RNS.log("Deleting conversation with "+RNS.prettyhexrep(context_dest), RNS.LOG_DEBUG)
         db = sqlite3.connect(self.db_path)
         dbc = db.cursor()
 
@@ -687,8 +699,19 @@ class SidebandCore():
 
         db.close()
 
+    def _db_delete_announce(self, context_dest):
+        RNS.log("Deleting announce with "+RNS.prettyhexrep(context_dest), RNS.LOG_DEBUG)
+        db = sqlite3.connect(self.db_path)
+        dbc = db.cursor()
+
+        query = "delete from announce where (source=:ctx_dst);"
+        dbc.execute(query, {"ctx_dst": context_dest})
+        db.commit()
+
+        db.close()
+
     def _db_create_conversation(self, context_dest, name = None, trust = False):
-        RNS.log("Creating conversation for "+RNS.prettyhexrep(context_dest))
+        RNS.log("Creating conversation for "+RNS.prettyhexrep(context_dest), RNS.LOG_DEBUG)
         db = sqlite3.connect(self.db_path)
         dbc = db.cursor()
 
@@ -859,21 +882,27 @@ class SidebandCore():
         db = sqlite3.connect(self.db_path)
         dbc = db.cursor()
 
+        query = "delete from announce where id is NULL or id not in (select id from announce order by received desc limit "+str(self.MAX_ANNOUNCES)+")"
+        dbc.execute(query)
+
         query = "delete from announce where (source=:source);"
         dbc.execute(query, {"source": destination_hash})
 
-        query = "INSERT INTO announce (received, source, data, dest_type) values (?, ?, ?, ?)"
+        now = time.time()
+        hash_material = str(time).encode("utf-8")+destination_hash+app_data+dest_type.encode("utf-8")
+        announce_hash = RNS.Identity.full_hash(hash_material)
+
+        query = "INSERT INTO announce (id, received, source, data, dest_type) values (?, ?, ?, ?, ?)"
         data = (
-            time.time(),
+            announce_hash,
+            now,
             destination_hash,
             app_data,
             dest_type,
         )
 
         dbc.execute(query, data)
-
-        query = "delete from announce where id not in (select id from announce order by received desc limit "+str(self.MAX_ANNOUNCES)+")"
-        dbc.execute(query)
+        db.commit()
 
         db.commit()
         db.close()
@@ -909,10 +938,42 @@ class SidebandCore():
     def _service_jobs(self):
         if self.is_service:
             while True:
-                time.sleep(SidebandCore.JOB_INTERVAL)
+                time.sleep(SidebandCore.SERVICE_JOB_INTERVAL)
                 if self.getstate("wants.announce"):
                     self.lxmf_announce()
 
+    def _periodic_jobs(self):
+        if self.is_service or self.is_standalone:
+            while True:
+                time.sleep(SidebandCore.PERIODIC_JOBS_INTERVAL)
+                if self.config["lxmf_periodic_sync"] == True:
+                    if self.getpersistent("lxmf.lastsync") == None:
+                        self.setpersistent("lxmf.lastsync", time.time())
+                    else:
+                        now = time.time()
+                        syncinterval = self.config["lxmf_sync_interval"]
+                        lastsync = self.getpersistent("lxmf.lastsync")
+                        nextsync = lastsync+syncinterval
+
+                        RNS.log("Last sync was "+RNS.prettytime(now-lastsync)+" ago", RNS.LOG_DEBUG)
+                        RNS.log("Next sync is "+("in "+RNS.prettytime(nextsync-now) if nextsync-now > 0 else "now"), RNS.LOG_DEBUG)
+                        if now > nextsync:
+                            if self.request_lxmf_sync():
+                                RNS.log("Scheduled LXMF sync succeeded", RNS.LOG_DEBUG)
+                                self.setpersistent("lxmf.lastsync", time.time())
+                                self.setpersistent("lxmf.syncretrying", False)
+                            else:
+                                if not self.getpersistent("lxmf.syncretrying"):
+                                    RNS.log("Scheduled LXMF sync failed, retrying in "+RNS.prettytime(SidebandCore.PERIODIC_SYNC_RETRY), RNS.LOG_DEBUG)
+                                    self.setpersistent("lxmf.lastsync", lastsync+SidebandCore.PERIODIC_SYNC_RETRY)
+                                    self.setpersistent("lxmf.syncretrying", True)
+                                else:
+                                    RNS.log("Retry of scheduled LXMF sync failed too, waiting until next scheduled sync to try again", RNS.LOG_DEBUG)
+                                    self.setpersistent("lxmf.lastsync", time.time())
+                                    self.setpersistent("lxmf.syncretrying", False)
+
+
+
     def __start_jobs_deferred(self):
         if self.config["start_announce"]:
             self.lxmf_announce()
@@ -920,6 +981,10 @@ class SidebandCore():
         if self.is_service:
             self.service_thread = threading.Thread(target=self._service_jobs, daemon=True)
             self.service_thread.start()
+
+        if self.is_standalone or self.is_service:
+            self.periodic_thread = threading.Thread(target=self._periodic_jobs, daemon=True)
+            self.periodic_thread.start()
         
     def __start_jobs_immediate(self):
         if self.log_verbose:
