@@ -1,14 +1,17 @@
 import RNS
+import time
 
-from kivy.metrics import dp
+from kivy.metrics import dp,sp
 from kivy.uix.boxlayout import BoxLayout
 from kivy.properties import StringProperty, BooleanProperty
 from kivymd.uix.list import MDList, IconLeftWidget, IconRightWidget, OneLineAvatarIconListItem
 from kivymd.uix.menu import MDDropdownMenu
 from kivy.uix.gridlayout import GridLayout
 from kivy.uix.boxlayout import BoxLayout
+from kivy.clock import Clock
+from kivy.core.clipboard import Clipboard
 
-from kivymd.uix.button import MDFlatButton
+from kivymd.uix.button import MDRectangleFlatButton
 from kivymd.uix.dialog import MDDialog
 
 
@@ -22,6 +25,7 @@ class MsgSync(BoxLayout):
 
 class ConvSettings(BoxLayout):
     disp_name = StringProperty()
+    context_dest = StringProperty()
     trusted = BooleanProperty()
 
 
@@ -31,6 +35,7 @@ class Conversations():
         self.context_dests = []
         self.added_item_dests = []
         self.list = None
+        self.conversation_dropdown = None
         self.update()
 
     def reload(self):
@@ -55,6 +60,8 @@ class Conversations():
         self.app.sideband.setstate("app.flags.new_conversations", False)
 
     def update_widget(self):
+        us = time.time()
+        RNS.log("Updating conversation list widgets", RNS.LOG_DEBUG)
         if self.list == None:
             self.list = MDList()
             
@@ -82,21 +89,17 @@ class Conversations():
 
                 def gen_edit(dest, item):
                     def x():
+                        dest = self.conversation_dropdown.context_dest
                         try:
                             disp_name = self.app.sideband.raw_display_name(dest)
                             is_trusted = self.app.sideband.is_trusted(dest)
 
-                            yes_button = MDFlatButton(
-                                text="Save",
-                                font_size=dp(20),
-                            )
-                            no_button = MDFlatButton(
-                                text="Cancel",
-                                font_size=dp(20),
-                            )
-                            dialog_content = ConvSettings(disp_name=disp_name, trusted=is_trusted)
+                            yes_button = MDRectangleFlatButton(text="Save",font_size=sp(18), theme_text_color="Custom", line_color=self.app.color_accept, text_color=self.app.color_accept)
+                            no_button = MDRectangleFlatButton(text="Cancel",font_size=sp(18))
+                            dialog_content = ConvSettings(disp_name=disp_name, context_dest=RNS.hexrep(dest, delimit=False), trusted=is_trusted)
                             dialog = MDDialog(
-                                title="Conversation with "+RNS.prettyhexrep(dest),
+                                title="Edit Conversation",
+                                text= "With "+RNS.prettyhexrep(dest),
                                 type="custom",
                                 content_cls=dialog_content,
                                 buttons=[ yes_button, no_button ],
@@ -121,7 +124,10 @@ class Conversations():
                                     RNS.log("Error while saving conversation settings: "+str(e), RNS.LOG_ERROR)
 
                                 dialog.dismiss()
-                                self.reload()
+
+                                def cb(dt):
+                                    self.reload()
+                                Clock.schedule_once(cb, 0.2)
 
                             def dl_no(s):
                                 dialog.dismiss()
@@ -137,14 +143,12 @@ class Conversations():
 
                 def gen_clear(dest, item):
                     def x():
-                        yes_button = MDFlatButton(
-                            text="Yes",
-                        )
-                        no_button = MDFlatButton(
-                            text="No",
-                        )
+                        dest = self.conversation_dropdown.context_dest
+                        yes_button = MDRectangleFlatButton(text="Yes",font_size=sp(18), theme_text_color="Custom", line_color=self.app.color_reject, text_color=self.app.color_reject)
+                        no_button = MDRectangleFlatButton(text="No",font_size=sp(18))
+
                         dialog = MDDialog(
-                            text="Clear all messages in conversation?",
+                            title="Clear all messages in conversation?",
                             buttons=[ yes_button, no_button ],
                             # elevation=0,
                         )
@@ -162,21 +166,19 @@ class Conversations():
 
                 def gen_del(dest, item):
                     def x():
-                        yes_button = MDFlatButton(
-                            text="Yes",
-                        )
-                        no_button = MDFlatButton(
-                            text="No",
-                        )
+                        yes_button = MDRectangleFlatButton(text="Yes",font_size=sp(18), theme_text_color="Custom", line_color=self.app.color_reject, text_color=self.app.color_reject)
+                        no_button = MDRectangleFlatButton(text="No",font_size=sp(18))
                         dialog = MDDialog(
-                            text="Delete conversation?",
+                            title="Delete conversation?",
                             buttons=[ yes_button, no_button ],
                             # elevation=0,
                         )
                         def dl_yes(s):
                             dialog.dismiss()
-                            self.app.sideband.delete_conversation(dest)
-                            self.reload()
+                            self.app.sideband.delete_conversation(self.conversation_dropdown.context_dest)
+                            def cb(dt):
+                                self.reload()
+                            Clock.schedule_once(cb, 0.2)
                         def dl_no(s):
                             dialog.dismiss()
 
@@ -186,49 +188,70 @@ class Conversations():
                         dialog.open()
                     return x
 
-                dm_items = [
-                    {
-                        "viewclass": "OneLineListItem",
-                        "text": "Edit",
-                        "height": dp(40),
-                        "on_release": gen_edit(context_dest, item)
-                    },
-                    {
-                        "text": "Clear Messages",
-                        "viewclass": "OneLineListItem",
-                        "height": dp(40),
-                        "on_release": gen_clear(context_dest, item)
-                    },
-                    {
-                        "text": "Delete Conversation",
-                        "viewclass": "OneLineListItem",
-                        "height": dp(40),
-                        "on_release": gen_del(context_dest, item)
-                    }
-                ]
+                def gen_copy_addr(dest, item):
+                    def x():
+                        Clipboard.copy(RNS.hexrep(dest, delimit=False))
+                        item.dmenu.dismiss()
+                    return x
+
+                if self.conversation_dropdown == None:
+                    dmi_h = 40
+                    dm_items = [
+                        {
+                            "viewclass": "OneLineListItem",
+                            "text": "Edit",
+                            "height": dp(dmi_h),
+                            "on_release": gen_edit(context_dest, item)
+                        },
+                        {
+                            "text": "Copy Address",
+                            "viewclass": "OneLineListItem",
+                            "height": dp(dmi_h),
+                            "on_release": gen_copy_addr(context_dest, item)
+                        },
+                        {
+                            "text": "Clear Messages",
+                            "viewclass": "OneLineListItem",
+                            "height": dp(dmi_h),
+                            "on_release": gen_clear(context_dest, item)
+                        },
+                        {
+                            "text": "Delete Conversation",
+                            "viewclass": "OneLineListItem",
+                            "height": dp(dmi_h),
+                            "on_release": gen_del(context_dest, item)
+                        }
+                    ]
+
+                    self.conversation_dropdown = MDDropdownMenu(
+                        caller=None,
+                        items=dm_items,
+                        position="auto",
+                        width_mult=4,
+                        elevation=1,
+                        radius=dp(3),
+                        opening_transition="linear",
+                        opening_time=0.0,
+                    )
 
                 item.iconr = IconRightWidget(icon="dots-vertical");
-                
-                item.dmenu = MDDropdownMenu(
-                    caller=item.iconr,
-                    items=dm_items,
-                    position="auto",
-                    width_mult=4,
-                    elevation=1,
-                    radius=dp(3),
-                )
+                item.dmenu = self.conversation_dropdown
 
-                def callback_factory(ref):
+                def callback_factory(ref, dest):
                     def x(sender):
+                        self.conversation_dropdown.context_dest = dest
+                        ref.dmenu.caller = ref.iconr
                         ref.dmenu.open()
                     return x
 
-                item.iconr.bind(on_release=callback_factory(item))
+                item.iconr.bind(on_release=callback_factory(item, context_dest))
 
                 item.add_widget(item.iconr)
                 
                 self.added_item_dests.append(context_dest)
                 self.list.add_widget(item)
 
+        RNS.log("Updated conversation list widgets in "+RNS.prettytime(time.time()-us), RNS.LOG_DEBUG)
+
     def get_widget(self):
         return self.list
\ No newline at end of file
