@@ -47,6 +47,44 @@ MDNavigationLayout:
                         height: self.texture_size[1]
 
 
+        MDScreen:
+            name: "exit_screen"
+                 
+            AnchorLayout:
+                anchor_x: "center"
+                anchor_y: "center"
+                padding: dp(64)
+
+                BoxLayout:
+                    spacing: dp(36)
+                    orientation: 'vertical'
+                    size_hint_y: None
+
+                    MDLabel:
+                        id: connecting_info
+                        halign: "center"
+                        text: "Please Wait"
+                        font_size: "32dp"
+                        size_hint_y: None
+                        text_size: self.width, None
+                        height: self.texture_size[1]
+
+                    MDIconButton:
+                        pos_hint: {"center_x": .5, "center_y": .5}
+                        # icon: "close-network-outline"
+                        icon: "waves"
+                        icon_size: "72dp"
+
+                    MDLabel:
+                        id: connecting_info
+                        halign: "center"
+                        text: "Dissolving Reticulum"
+                        font_size: "32dp"
+                        size_hint_y: None
+                        text_size: self.width, None
+                        height: self.texture_size[1]
+
+
         MDScreen:
             name: "conversations_screen"
             
@@ -130,6 +168,7 @@ MDNavigationLayout:
                         max_height: dp(100)
 
                     MDRectangleFlatIconButton:
+                        id: message_send_button
                         icon: "transfer-up"
                         text: "Send"
                         padding: [dp(10), dp(13), dp(10), dp(14)]
@@ -513,9 +552,72 @@ MDNavigationLayout:
                         height: self.minimum_height
                         padding: [dp(35), dp(16), dp(35), dp(16)]
 
+                        MDLabel:
+                            id: guide_info1
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
 
                         MDLabel:
-                            id: guide_info
+                            id: guide_info2
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info3
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info4
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info5
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info6
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info7
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info8
+                            markup: True
+                            text: ""
+                            size_hint_y: None
+                            text_size: self.width, None
+                            height: self.texture_size[1]
+
+                        MDLabel:
+                            id: guide_info9
                             markup: True
                             text: ""
                             size_hint_y: None
@@ -741,144 +843,206 @@ MDNavigationLayout:
 
                     MDBoxLayout:
                         orientation: "vertical"
-                        spacing: "24dp"
+                        spacing: 0
                         size_hint_y: None
                         height: self.minimum_height
-                        padding: [dp(28), dp(16), dp(28), dp(16)]
-                        
-
-                        MDLabel:
-                            text: ""
-                            font_style: "H6"
-
-                        MDLabel:
-                            text: "User Options"
-                            font_style: "H6"
-
-                        MDTextField:
-                            id: settings_display_name
-                            hint_text: "Display Name"
-                            text: ""
-                            max_text_length: 128
-                            font_size: dp(24)
-
-                        MDTextField:
-                            id: settings_lxmf_address
-                            hint_text: "Your LXMF Address"
-                            text: ""
-                            disabled: False
-                            max_text_length: 32
-                            font_size: dp(24)
-
-                        MDTextField:
-                            id: settings_propagation_node_address
-                            hint_text: "LXMF Propagation Node"
-                            disabled: False
-                            text: ""
-                            max_text_length: 32
-                            font_size: dp(24)
-
-                        MDTextField:
-                            id: settings_home_node_address
-                            hint_text: "Nomad Network Home Node"
-                            disabled: False
-                            text: ""
-                            max_text_length: 32
-                            font_size: dp(24)
+                        padding: [0, 0, 0, 0]
 
                         MDBoxLayout:
-                            orientation: "horizontal"
+                            orientation: "vertical"
+                            spacing: "16dp"
                             size_hint_y: None
-                            padding: [0,0,dp(24),0]
-                            height: dp(48)
+                            height: self.minimum_height
+                            padding: [dp(28), dp(16), dp(28), dp(16)]
                             
+
                             MDLabel:
-                                text: "Dark Mode UI"
+                                text: ""
                                 font_style: "H6"
 
-                            MDSwitch:
-                                id: settings_dark_ui
-                                pos_hint: {"center_y": 0.3}
-                                active: False
-
-                        MDBoxLayout:
-                            orientation: "horizontal"
-                            size_hint_y: None
-                            padding: [0,0,dp(24),0]
-                            height: dp(48)
-                            
                             MDLabel:
-                                text: "Announce At App Startup"
+                                text: "User Options"
                                 font_style: "H6"
 
-                            MDSwitch:
-                                id: settings_start_announce
-                                pos_hint: {"center_y": 0.3}
-                                active: False
+                            MDTextField:
+                                id: settings_display_name
+                                hint_text: "Display Name"
+                                text: ""
+                                max_text_length: 128
+                                font_size: dp(24)
 
-                        MDBoxLayout:
-                            orientation: "horizontal"
-                            size_hint_y: None
-                            padding: [0,0,dp(24),0]
-                            height: dp(48)
-                            
-                            MDLabel:
-                                text: "Send via Propagation Node by default"
-                                font_style: "H6"
-
-                            MDSwitch:
-                                id: settings_lxmf_delivery_by_default
-                                pos_hint: {"center_y": 0.3}
+                            MDTextField:
+                                id: settings_lxmf_address
+                                hint_text: "Your LXMF Address"
+                                text: ""
                                 disabled: False
-                                active: False
+                                max_text_length: 32
+                                font_size: dp(24)
 
-                        MDBoxLayout:
-                            orientation: "horizontal"
-                            size_hint_y: None
-                            padding: [0,0,dp(24),0]
-                            height: dp(48)
-                            
-                            MDLabel:
-                                text: "Limit each sync to 3 messages"
-                                font_style: "H6"
-
-                            MDSwitch:
-                                id: settings_lxmf_sync_limit
-                                pos_hint: {"center_y": 0.3}
+                            MDTextField:
+                                id: settings_propagation_node_address
+                                hint_text: "LXMF Propagation Node"
                                 disabled: False
-                                active: False
+                                text: ""
+                                max_text_length: 32
+                                font_size: dp(24)
+
+                            MDTextField:
+                                id: settings_home_node_address
+                                hint_text: "Nomad Network Home Node"
+                                disabled: False
+                                text: ""
+                                max_text_length: 32
+                                font_size: dp(24)
+
 
                         MDBoxLayout:
-                            orientation: "horizontal"
+                            orientation: "vertical"
+                            # spacing: "24dp"
                             size_hint_y: None
-                            padding: [0,0,dp(24),0]
-                            height: dp(48)
-                            
-                            MDLabel:
-                                text: "Use Home Node as Broadcast Repeater"
-                                font_style: "H6"
+                            height: self.minimum_height
+                            padding: [dp(28), dp(16), dp(28), dp(16)]
 
-                            MDSwitch:
-                                id: settings_home_node_as_broadcast_repeater
-                                pos_hint: {"center_y": 0.3}
-                                active: False
-                                disabled: True
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Notifications"
+                                    font_style: "H6"
 
-                        MDBoxLayout:
-                            orientation: "horizontal"
-                            size_hint_y: None
-                            padding: [0,0,dp(24),0]
-                            height: dp(48)
-                            
-                            MDLabel:
-                                text: "Send Telemetry to Home Node"
-                                font_style: "H6"
+                                MDSwitch:
+                                    id: settings_notifications_on
+                                    pos_hint: {"center_y": 0.3}
+                                    active: True
 
-                            MDSwitch:
-                                id: settings_telemetry_to_home_node
-                                pos_hint: {"center_y": 0.3}
-                                disabled: True
-                                active: False
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Dark Mode UI"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_dark_ui
+                                    pos_hint: {"center_y": 0.3}
+                                    active: False
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Announce At App Startup"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_start_announce
+                                    pos_hint: {"center_y": 0.3}
+                                    active: False
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Send via Propagation Node by default"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_lxmf_delivery_by_default
+                                    pos_hint: {"center_y": 0.3}
+                                    disabled: False
+                                    active: False
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Limit each sync to 3 messages"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_lxmf_sync_limit
+                                    pos_hint: {"center_y": 0.3}
+                                    disabled: False
+                                    active: False
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    id: settings_lxmf_sync_periodic
+                                    text: "Sync with Propagation Node periodically"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_lxmf_periodic_sync
+                                    pos_hint: {"center_y": 0.3}
+                                    disabled: False
+                                    active: False
+
+                            MDBoxLayout:
+                                id: lxmf_syncslider_container
+                                orientation: "vertical"
+                                size_hint_y: None
+                                padding: [0,0,dp(0),0]
+                                height: dp(68)
+
+                                MDSlider
+                                    min: 300
+                                    max: 172800
+                                    value: 43200
+                                    id: settings_lxmf_sync_interval
+                                    sensitivity: "all"
+                                    hint: False
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Use Home Node as Broadcast Repeater"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_home_node_as_broadcast_repeater
+                                    pos_hint: {"center_y": 0.3}
+                                    active: False
+                                    disabled: True
+
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Send Telemetry to Home Node"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_telemetry_to_home_node
+                                    pos_hint: {"center_y": 0.3}
+                                    disabled: True
+                                    active: False
         
 
     MDNavigationDrawer:
@@ -887,6 +1051,7 @@ MDNavigationLayout:
 
         ContentNavigationDrawer:
             ScrollView:
+                id: nav_scrollview
                 DrawerList:
                     id: md_list
                     
@@ -988,7 +1153,7 @@ MDNavigationLayout:
                                 on_release: root.ids.screen_manager.app.quit_action(self)
 
 <ListLXMessageCard>:
-    style: "filled"
+    style: "outlined"
     elevation: 2
     padding: dp(8)
     radius: [dp(4), dp(4), dp(4), dp(4)]
@@ -1031,34 +1196,43 @@ MDNavigationLayout:
     orientation: "vertical"
     spacing: "24dp"
     size_hint_y: None
+    padding: [0, 0, 0, dp(16)]
     height: self.minimum_height+dp(24)
 
+    MDProgressBar:
+        id: sync_progress
+        value: 0
+
     MDLabel:
         id: sync_status
         hint_text: "Name"
         text: "Initiating sync..."
 
-    MDProgressBar:
-        id: sync_progress
-        value: 0
-
 <ConvSettings>
     orientation: "vertical"
-    spacing: "24dp"
+    spacing: "16dp"
     size_hint_y: None
-    height: dp(148)
+    padding: [0, 0, 0, dp(8)]
+    height: self.minimum_height
+
+    MDTextField:
+        id: dest_field
+        hint_text: "Address"
+        text: root.context_dest
+        # disabled: True
+        font_size: dp(18)
 
     MDTextField:
         id: name_field
         hint_text: "Name"
         text: root.disp_name
-        font_size: dp(24)
+        font_size: dp(18)
 
     MDBoxLayout:
         orientation: "horizontal"
         # spacing: "24dp"
         size_hint_y: None
-        padding: [0,0,dp(24),0]
+        padding: [0,0,dp(8),0]
         height: dp(48)
         MDLabel:
             id: trusted_switch_label
@@ -1067,6 +1241,7 @@ MDNavigationLayout:
 
         MDSwitch:
             id: trusted_switch
+            pos_hint: {"center_y": 0.43}
             active: root.trusted
 
 <NewConv>
@@ -1093,7 +1268,7 @@ MDNavigationLayout:
     MDBoxLayout:
         orientation: "horizontal"
         size_hint_y: None
-        padding: [0,0,dp(24),0]
+        padding: [0,0,dp(8),0]
         height: dp(48)
         MDLabel:
             id: "trusted_switch_label"
