@@ -2,19 +2,21 @@ import time
 import RNS
 import LXMF
 
-from kivy.metrics import dp
+from kivy.metrics import dp,sp
 from kivy.core.clipboard import Clipboard
 from kivymd.uix.card import MDCard
 from kivymd.uix.menu import MDDropdownMenu
-from kivymd.uix.behaviors import RoundedRectangularElevationBehavior, FakeRectangularElevationBehavior
-# from kivymd.uix.behaviors import CommonElevationBehavior
+# from kivymd.uix.behaviors import RoundedRectangularElevationBehavior, FakeRectangularElevationBehavior
+from kivymd.uix.behaviors import CommonElevationBehavior
 from kivy.properties import StringProperty, BooleanProperty
 from kivy.uix.gridlayout import GridLayout
 from kivy.uix.boxlayout import BoxLayout
+from kivy.clock import Clock
 
-from kivymd.uix.button import MDFlatButton
+from kivymd.uix.button import MDRectangleFlatButton
 from kivymd.uix.dialog import MDDialog
 
+
 if RNS.vendor.platformutils.get_platform() == "android":
     from ui.helpers import ts_format, mdc
     from ui.helpers import color_received, color_delivered, color_propagated, color_failed, color_unknown, intensity_msgs_dark, intensity_msgs_light
@@ -22,8 +24,8 @@ else:
     from .helpers import ts_format, mdc
     from .helpers import color_received, color_delivered, color_propagated, color_failed, color_unknown, intensity_msgs_dark, intensity_msgs_light
 
-# class ListLXMessageCard(MDCard, CommonElevationBehavior):
-class ListLXMessageCard(MDCard, FakeRectangularElevationBehavior):
+class ListLXMessageCard(MDCard):
+# class ListLXMessageCard(MDCard, FakeRectangularElevationBehavior):
     text = StringProperty()
     heading = StringProperty()
 
@@ -67,6 +69,11 @@ class Messages():
 
         for w in self.widgets:
             m = w.m
+            if self.app.sideband.config["dark_ui"]:
+                w.line_color = (1.0, 1.0, 1.0, 0.25)
+            else:
+                w.line_color = (1.0, 1.0, 1.0, 0.5)
+
             if m["state"] == LXMF.LXMessage.SENDING or m["state"] == LXMF.LXMessage.OUTBOUND:
                 msg = self.app.sideband.message(m["hash"])
                 if msg["state"] == LXMF.LXMessage.DELIVERED:
@@ -155,21 +162,21 @@ class Messages():
 
                 def gen_del(mhash, item):
                     def x():
-                        yes_button = MDFlatButton(
-                            text="Yes",
-                        )
-                        no_button = MDFlatButton(
-                            text="No",
-                        )
+                        yes_button = MDRectangleFlatButton(text="Yes",font_size=sp(18), theme_text_color="Custom", line_color=self.app.color_reject, text_color=self.app.color_reject)
+                        no_button = MDRectangleFlatButton(text="No",font_size=sp(18))
                         dialog = MDDialog(
-                            text="Delete message?",
+                            title="Delete message?",
                             buttons=[ yes_button, no_button ],
                             # elevation=0,
                         )
                         def dl_yes(s):
                             dialog.dismiss()
                             self.app.sideband.delete_message(mhash)
-                            self.reload()
+
+                            def cb(dt):
+                                self.reload()
+                            Clock.schedule_once(cb, 0.2)
+
                         def dl_no(s):
                             dialog.dismiss()
 
@@ -209,6 +216,8 @@ class Messages():
                     width_mult=4,
                     elevation=1,
                     radius=dp(3),
+                    opening_transition="linear",
+                    opening_time=0.0,
                 )
 
                 def callback_factory(ref):
